mod components;
use axum::{extract::State, response::IntoResponse};
use axum_controller::*;
use hypertext::{maud, GlobalAttributes, Renderable};

use crate::{ui::components::*, AppState};

pub mod html_elements {
    use hypertext::elements;
    pub use hypertext::html_elements::*;

    elements! {
        bla {
            blub
        }
        my_element {
            my_attribute
        }
    }
}

pub struct UiController {}

#[controller(
    state = AppState
)]
impl UiController {
    #[route(GET "/")]
    async fn index(State(_): State<AppState>) -> impl IntoResponse {
        main_page(maud! {
                    div class="container mx-auto p-4" {
                        h1 class="text-2xl font-bold mb-4" {
                            "LLM Chat App"
                        }
                        div class="bg-white p-6 rounded-lg shadow-md" {
                            div id="chat" class="mb-4" {
                                // Chat messages will appear here
                            }
                            form id="chat-form" {
                                textarea id="user-input" class="w-full p-2 border rounded-lg mb-2" placeholder="Type your message..." {}
                                button type="submit" class="bg-blue-500 text-white p-2 rounded-lg" {
                                    "Send"
                                }
                            }
                        }
                    }
                    script {
                        (hypertext::Raw("
                            console.log(\"asd\");
                            document.getElementById('chat-form').addEventListener('submit', function(event) {
                                event.preventDefault();
                                const userInput = document.getElementById('user-input').value;
                                const chatContainer = document.getElementById('chat');
                                chatContainer.innerHTML += `<div class='mb-2'><strong>You:</strong> ${userInput}</div>`;
                                document.getElementById('user-input').value = '';
                                console.log(\"asd\");

                                // Mock response from LLM
                                setTimeout(() => {
                                    chatContainer.innerHTML += `<div class='mb-2'><strong>LLM:</strong> This is a mock response.</div>`;
                                }, 1000);
                            });
                        "))
                    }
                }
            )
        .render()
    }
}
